/**
 * Keystore
 * Storage for secrets and keys. When a user creates and encrypts Data Encryption Keys and Keypairs, they are stored in the Keystore. A user cannot access the Vault without first using the Keystore. In the current implementation the Keystore functionality is implemented by meeco-keystore.
 *
 * The version of the OpenAPI document: 6.2.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
import { HttpClient, HttpHeaders, HttpResponse, HttpEvent, HttpParameterCodec } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ClaimDelegationRequest } from '../model/models';
import { DelegationResponse } from '../model/models';
import { PostChildUserRequest } from '../model/models';
import { PostDelegationRequest } from '../model/models';
import { ReencryptDelegationKekRequest } from '../model/models';
import { ShareDelegationKekRequest } from '../model/models';
import { Configuration } from '../configuration';
export declare class DelegationService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    encoder: HttpParameterCodec;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    private addToHttpParams;
    private addToHttpParamsRecursive;
    /**
     * Creates a child user
     * A parent/child business case is a special case of delegation where a child account is created by the parent account. The child account cannot login.  The first step is running &#x60;POST /child_users&#x60; in the vault thus creating a child user in the vault.  This endpoint allows an existing user (&#x3D; delegate user) to create a child account (&#x3D; owner account) in the keystore.  The KEK of the child account will be initially encrypted with the KEK of the parent keystore account.  In the terminology of the generic delegation case  * a child account is the owner account * a parent account is the delegate account
     * @param postChildUserRequest
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    childUsersPost(postChildUserRequest?: PostChildUserRequest, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<any>;
    childUsersPost(postChildUserRequest?: PostChildUserRequest, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpResponse<any>>;
    childUsersPost(postChildUserRequest?: PostChildUserRequest, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpEvent<any>>;
    /**
     * Claims a delegation record
     * Claims a delegation record with a delegation token.  Once the delegate user has accepted a delegation invitation in the vault the delegate user can retrieve the delegation token from the connection and claim the delegation record using this endpoint.  The delegate user is expected to submit a signature signed with the the delegate user\&#39;s private key from the delegation connection in the vault. If the signature is verified successfully the delegaton relation is established and the delegate user obtains access to a subset of keys of the account owner.
     * @param delegationToken
     * @param claimDelegationRequest
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    delegationsDelegationTokenClaimPost(delegationToken: string, claimDelegationRequest?: ClaimDelegationRequest, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
    }): Observable<DelegationResponse>;
    delegationsDelegationTokenClaimPost(delegationToken: string, claimDelegationRequest?: ClaimDelegationRequest, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
    }): Observable<HttpResponse<DelegationResponse>>;
    delegationsDelegationTokenClaimPost(delegationToken: string, claimDelegationRequest?: ClaimDelegationRequest, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
    }): Observable<HttpEvent<DelegationResponse>>;
    /**
     * Deletes a delegation
     * Deletes a delegation identified by its token.Both the delegate user and the account owner may delete a delegation record.  This endpoint is deprecated for user authentication in favour of an inbuilt backend to backend call from the vault. Downgrading or deleting a delegation connection in the vault will automatically delete the corresponding keystore delegation.
     * @param delegationToken
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     * @deprecated
     */
    delegationsDelegationTokenDelete(delegationToken: string, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<any>;
    delegationsDelegationTokenDelete(delegationToken: string, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpResponse<any>>;
    delegationsDelegationTokenDelete(delegationToken: string, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpEvent<any>>;
    /**
     * Reads a delegation
     * Reads a delegation identified by its delegation token or &#x60;vault_account_owner_id&#x60;.  Both the account owner and the delegate user may read the delegation record, but the key encryption key is hidden for the account owner, because the KEK stored in the delegation record is for the delegate user, and can only be decrypted by the delegate user.
     * @param delegationToken  &#x60;delegation_token&#x60; or &#x60;vault_account_owner_id&#x60; of the delegation.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    delegationsDelegationTokenGet(delegationToken: string, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<any>;
    delegationsDelegationTokenGet(delegationToken: string, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpResponse<any>>;
    delegationsDelegationTokenGet(delegationToken: string, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpEvent<any>>;
    /**
     * Re-uploads account owner\&#39;s KEK re-encrypted with the delegate\&#39;s KEK.
     * Initially the account owner shares his/her KEK with the delegate user, and the KEK is encrypted with the public key belonging to the keypair of the delegate user from the vault connection between the account owner and the delegate user.This endpoint allows the delegate user to save the same KEK re-encrypted with the delegate\&#39;s KEK. Field &#x60;account_owner_kek_encrypted_with_connection_keypair&#x60; is set to &#x60;false&#x60;.
     * @param delegationToken
     * @param reencryptDelegationKekRequest
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    delegationsDelegationTokenReencryptPut(delegationToken: string, reencryptDelegationKekRequest?: ReencryptDelegationKekRequest, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<any>;
    delegationsDelegationTokenReencryptPut(delegationToken: string, reencryptDelegationKekRequest?: ReencryptDelegationKekRequest, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpResponse<any>>;
    delegationsDelegationTokenReencryptPut(delegationToken: string, reencryptDelegationKekRequest?: ReencryptDelegationKekRequest, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpEvent<any>>;
    /**
     * Share a key encryption key with the delegate user
     * Share a key encryption key with the delegate user.  Once the delegate user has accepted the delegation connection, the delegate user can claim the delegation record using the delegation token, and thus get access to a subset of account owner\&#39;s keys. But these keys are encrypted with the KEK of the account owner.   This endpoint allows the account owner to share the KEK with the delegate user. This KEK is encrypted with the public key belonging to the keypair of the delegate user from the vault connection between the account owner and the delegate user.  The account owner may call this endpoint multiple times in case a new KEK is generated and all account owner\&#39; keys are re-encrypted with the new KEK.  When the endpoint is called for the first time the backend also expects the public key belonging to the keypair of the delegate user from the vault connection between the account owner and the delegate user. This public key is required for the verification of the signature signed and added by the delegate user.
     * @param delegationToken
     * @param shareDelegationKekRequest
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    delegationsDelegationTokenSharePut(delegationToken: string, shareDelegationKekRequest?: ShareDelegationKekRequest, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<any>;
    delegationsDelegationTokenSharePut(delegationToken: string, shareDelegationKekRequest?: ShareDelegationKekRequest, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpResponse<any>>;
    delegationsDelegationTokenSharePut(delegationToken: string, shareDelegationKekRequest?: ShareDelegationKekRequest, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: undefined;
    }): Observable<HttpEvent<any>>;
    /**
     * Creates delegation token
     * Creates a delegation token.   This endpoint is the first step in setting up a delegation relation in the vault and the keystore. Any user who wants to grant other users delegation permissions can generate a delegation token via this endpoint.  * A user who grants delegation permissions is a _account owner_ * A user who receives delegation permission is a _delegate user_.  A delegation record and a random delegation token are created. This delegation token is used to identify the delegation record. The account owner can then add this delegation token to a delegation invitation in the vault. Once the invitee accepts the invitation he/she can retrieve the delegation token from the delegation connection and use token to claim this delegation record in the keystore. Once this delegation record in the keystore has been claimed, the delegate user obtains access to a subset of account owner\&#39;s keys.
     * @param postDelegationRequest
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    delegationsPost(postDelegationRequest?: PostDelegationRequest, observe?: 'body', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
    }): Observable<DelegationResponse>;
    delegationsPost(postDelegationRequest?: PostDelegationRequest, observe?: 'response', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
    }): Observable<HttpResponse<DelegationResponse>>;
    delegationsPost(postDelegationRequest?: PostDelegationRequest, observe?: 'events', reportProgress?: boolean, options?: {
        httpHeaderAccept?: 'application/json';
    }): Observable<HttpEvent<DelegationResponse>>;
}
